Temperature class

A class for holding a temperature. Can output temperature as Kelvin, Celsius or Fahrenheit. All results are returned as double.

Constructors

Temperature(double? _kelvin)

Properties

celsius → double?
Convert temperature to Celsius
no setter
fahrenheit → double?
Convert temperature to Fahrenheit
no setter
hashCode → int
The hash code for this object.
no setterinherited
kelvin → double?
Convert temperature to Kelvin
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited