Weather class

A class for storing a weather-query response from OpenWeatherMap. This includes various measures such as location, temperature, wind, snow, rain and humidity.

Constructors

Weather(Map<String, dynamic> jsonData)

Properties

areaName → String?
Name of the area, ex Mountain View, or Copenhagen Municipality
no setter
cloudiness → double?
The level of cloudiness in Okta (0-9 scale)
no setter
country → String?
Country code, ex US or DK
no setter
date → DateTime?
Date of the weather observation
no setter
hashCode → int
The hash code for this object.
no setterinherited
humidity → double?
Humidity in percent
no setter
latitude → double?
Latitude of the weather observation
no setter
longitude → double?
Longitude of the weather observation
no setter
pressure → double?
Pressure in Pascal
no setter
rainLast3Hours → double?
Rain fall last 3 hours measured in mm
no setter
rainLastHour → double?
Rain fall last hour measured in mm
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snowLast3Hours → double?
Snow fall last 3 hours measured in mm
no setter
snowLastHour → double?
Snow fall last 3 hours measured in mm
no setter
sunrise → DateTime?
Timestamp of sunrise
no setter
sunset → DateTime?
Timestamp of sunset
no setter
temperature → Temperature?
Mean Temperature. Available as Kelvin, Celsius and Fahrenheit.
no setter
tempFeelsLike → Temperature?
The 'feels like' Temperature. Available as Kelvin, Celsius and Fahrenheit.
no setter
tempMax → Temperature?
Max Temperature. Available as Kelvin, Celsius and Fahrenheit.
no setter
tempMin → Temperature?
Min Temperature. Available as Kelvin, Celsius and Fahrenheit.
no setter
weatherConditionCode → int?
Weather condition codes
no setter
weatherDescription → String?
A long description of the weather
no setter
weatherIcon → String?
Icon depicting current weather
no setter
weatherMain → String?
A brief description of the weather
no setter
windDegree → double?
Wind direction in degrees
no setter
windGust → double?
Wind gust in m/s
no setter
windSpeed → double?
Wind speed in m/s
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>?
The original JSON data from the API
toString() → String
The weather data formatted as a string with newlines
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited